==> haskell-cassava-0.4.5.0-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cassava/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.0
id: cassava-0.4.5.0-16a8710c3a0da375311b9db5f9f0d63e
key: cassa_HBrMWiH3yz23sEBshQWh49
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/cassava-0.4.5.0
hs-libraries: HScassava-0.4.5.0-HBrMWiH3yz23sEBshQWh49
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.4.5.0-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cassava/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.0
id: cassava-0.4.5.0-5561f7a2cf4fbc4e852eacf71d5b8fea
key: cassa_JwfoPeUsgdT5QHwlI8utaR
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/cassava-0.4.5.0
hs-libraries: HScassava-0.4.5.0-JwfoPeUsgdT5QHwlI8utaR
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
